@@ -284,6 +284,7 @@ eel_debug_show_pixbuf_in_external_viewer (const GdkPixbuf *pixbuf,
 	char *command;
 	char *file_name;
 	gboolean save_result;
+	int ignore;
 
 	g_return_if_fail (pixbuf != NULL);
 	g_return_if_fail (viewer_name != NULL);
@@ -305,7 +306,7 @@ eel_debug_show_pixbuf_in_external_viewer (const GdkPixbuf *pixbuf,
 	
 	command = g_strdup_printf ("%s %s", viewer_name, file_name);
 
-	(void) system (command);
+	ignore = system (command);
 	g_free (command);
 	remove (file_name);
 	g_free (file_name);
