@@ -33,7 +33,7 @@
 #include "eel-string.h"
 #include <gconf/gconf-client.h>
 #include <gconf/gconf.h>
-#include <gtk/gtksignal.h>
+#include <gtk/gtk.h>
 
 /* An enumeration used for updating auto-storage variables in a type-specific way. 
  * FIXME: there is another enumeration like this in eel-global-preferences.c,
@@ -43,7 +43,8 @@ typedef enum {
 	PREFERENCE_BOOLEAN = 1,
 	PREFERENCE_INTEGER,
 	PREFERENCE_STRING,
-	PREFERENCE_STRING_ARRAY
+	PREFERENCE_STRING_ARRAY,
+	PREFERENCE_STRING_ARRAY_AS_QUARKS
 } PreferenceType;
 
 /*
@@ -679,6 +680,30 @@ update_auto_string_array (gpointer data, gpointer callback_data)
 	*(char ***)storage = value ? g_strdupv (value) : NULL;
 }
 
+static void
+update_auto_string_array_as_quarks (gpointer data, gpointer callback_data)
+{
+	GQuark **storage;
+	char **value;
+	int i = 0;
+	
+	g_assert (data != NULL);
+	g_assert (callback_data != NULL);
+
+	storage = (GQuark **)data;
+	value = (char **)callback_data;
+
+	g_free (*storage);
+	*storage = g_new (GQuark, g_strv_length (value) + 1);
+
+	if (value != NULL) {
+		for (i = 0; value[i] != NULL; ++i) {
+			(*storage)[i] = g_quark_from_string (value[i]);
+		}
+	}
+	(*storage)[i] = 0;
+}
+
 static void
 update_auto_integer_or_boolean (gpointer data, gpointer callback_data)
 {
@@ -717,6 +742,13 @@ preferences_entry_update_auto_storage (PreferencesEntry *entry)
 				new_string_array_value);
 		g_strfreev (new_string_array_value);
 		break;
+	case PREFERENCE_STRING_ARRAY_AS_QUARKS:
+		new_string_array_value = eel_preferences_get_string_array (entry->name);
+		g_list_foreach (entry->auto_storage_list,
+				update_auto_string_array_as_quarks,
+				new_string_array_value);
+		g_strfreev (new_string_array_value);
+		break;
 	case PREFERENCE_INTEGER:
 		new_int_value = eel_preferences_get_integer (entry->name);
 		g_list_foreach (entry->auto_storage_list,
@@ -923,6 +955,9 @@ preferences_entry_remove_auto_storage (PreferencesEntry *entry,
 			case PREFERENCE_STRING_ARRAY:
 				update_auto_string_array (storage, NULL);
 				break;
+			case PREFERENCE_STRING_ARRAY_AS_QUARKS:
+				update_auto_string_array_as_quarks (storage, NULL);
+				break;
 			case PREFERENCE_BOOLEAN:
 			case PREFERENCE_INTEGER:
 				update_auto_integer_or_boolean (storage, NULL);
@@ -1168,6 +1203,27 @@ eel_preferences_add_auto_string_array (const char   *name,
 	g_strfreev (value);
 }
 
+void
+eel_preferences_add_auto_string_array_as_quarks (const char *name,
+						 GQuark **storage)
+{
+	PreferencesEntry *entry;
+	char **value;
+
+	g_return_if_fail (name != NULL);
+	g_return_if_fail (storage != NULL);
+	g_return_if_fail (preferences_is_initialized ());
+
+	entry = preferences_global_table_lookup_or_insert (name);
+	g_assert (entry != NULL);
+
+	preferences_entry_add_auto_storage (entry, storage, PREFERENCE_STRING_ARRAY_AS_QUARKS);
+
+	value = eel_preferences_get_string_array (entry->name);
+	update_auto_string_array_as_quarks (storage, value);
+	g_strfreev (value);
+}
+
 void
 eel_preferences_add_auto_integer (const char *name,
 				  int *storage)
