@@ -6,18 +6,7 @@ void
 test_init (int *argc,
 	   char ***argv)
 {
-/* Currently the gnome_program_init() function makes the test
- * programs hang for me.  Using just the gtk_init () works for
- * most tests, so I am using just that until the gnome_program_init ()
- * function is fixed or we learn how to use it properly. -re
- */
-#if 0
-	gnome_program_init ("test-eel-widgets", VERSION,
-			    libgnomeui_module_info_get (), *argc, *argv,
-			    NULL);
-#else
 	gtk_init (argc, argv);
-#endif
 
 	eel_make_warnings_and_criticals_stop_in_debugger ();
 }
